#include "quickcastwidget.h"
#include "ui_quickcastwidget.h"

#include <QtDeclarative>
#include <QTimer>

#include "model/media/phononmediaplayer.h"
#include "model/media/volumecontrol.h"
#include "model/streaming/streaming.h"
#include "model/streaming/metadata.h"
#include "model/icecast/stationrepository.h"
#include "model/icecast/stationtablemodel.h"

QuickCastWidget::QuickCastWidget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::QuickCastWidget)
{
    ui->setupUi(this);

    createModel();
    stationRepo->refresh();
    createDeclarativeView();

    ui->verticalLayout->addWidget(qDeclView);
}

void QuickCastWidget::createModel()
{
    mediaPlayer = new media::PhononMediaPlayer(this);
    stationRepo = new icecast::StationRepository(this);
    stationModel = new icecast::StationTableModel(stationRepo, this);
    streaming = new streaming::Streaming(stationRepo, mediaPlayer, this);
}

void QuickCastWidget::createDeclarativeView()
{
    qmlRegisterUncreatableType<streaming::MetaData>("Model.Streaming", 1, 0, "MetaData", tr("Instances only allowed from C++"));
    qmlRegisterUncreatableType<media::VolumeControl>("Model.Media", 1, 0, "VolumeControl", tr("Instances only allowed from C++"));

    qDeclView = new QDeclarativeView(this);

    QDeclarativeContext *context = qDeclView->rootContext();
    context->setContextProperty("stationModel", stationModel);
    context->setContextProperty("streaming", streaming);

    qDeclView->setAttribute(Qt::WA_OpaquePaintEvent);
    qDeclView->setAttribute(Qt::WA_NoSystemBackground);
    qDeclView->setResizeMode(QDeclarativeView::SizeRootObjectToView);
    qDeclView->setFocus();

    qDeclView->setSource(QUrl("qrc:/QuickCastRadio.qml"));
}


QuickCastWidget::~QuickCastWidget()
{
    delete ui;
}
